@@ -2,6 +2,8 @@ import dayjs from "dayjs";
 import { createI18n } from "vue-i18n";
 
 import("dayjs/locale/ar");
+import("dayjs/locale/bg");
+import("dayjs/locale/cs");
 import("dayjs/locale/de");
 import("dayjs/locale/el");
 import("dayjs/locale/en");
@@ -14,6 +16,7 @@ import("dayjs/locale/is");
 import("dayjs/locale/it");
 import("dayjs/locale/ja");
 import("dayjs/locale/ko");
+import("dayjs/locale/nb");
 import("dayjs/locale/nl-be");
 import("dayjs/locale/pl");
 import("dayjs/locale/pt-br");
@@ -27,8 +30,6 @@ import("dayjs/locale/uk");
 import("dayjs/locale/vi");
 import("dayjs/locale/zh-cn");
 import("dayjs/locale/zh-tw");
-import("dayjs/locale/cs");
-import("dayjs/locale/nb");
 
 // All i18n resources specified in the plugin `include` option can be loaded
 // at once using the import syntax
@@ -109,6 +110,7 @@ export function detectLocale() {
     case /^uk\b/.test(locale):
       locale = "uk";
       break;
+
     case /^vi\b/.test(locale):
       locale = "vi";
       break;
@@ -123,6 +125,9 @@ export function detectLocale() {
     case /^no\b/.test(locale):
       locale = "no";
       break;
+    case /^bg\b/.test(locale):
+      locale = "bg";
+      break;
     default:
       locale = "en";
   }
